pub struct DeletePreparedStatementFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeletePreparedStatement.
Deletes the prepared statement with the specified name from the specified workgroup.
Implementations
Sourceimpl DeletePreparedStatementFluentBuilder
impl DeletePreparedStatementFluentBuilder
Sourcepub fn as_input(&self) -> &DeletePreparedStatementInputBuilder
pub fn as_input(&self) -> &DeletePreparedStatementInputBuilder
Access the DeletePreparedStatement as a reference.
Sourcepub async fn send(
self,
) -> Result<DeletePreparedStatementOutput, SdkError<DeletePreparedStatementError, HttpResponse>>
pub async fn send( self, ) -> Result<DeletePreparedStatementOutput, SdkError<DeletePreparedStatementError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeletePreparedStatementOutput, DeletePreparedStatementError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeletePreparedStatementOutput, DeletePreparedStatementError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn statement_name(self, input: impl Into<String>) -> Self
pub fn statement_name(self, input: impl Into<String>) -> Self
The name of the prepared statement to delete.
Sourcepub fn set_statement_name(self, input: Option<String>) -> Self
pub fn set_statement_name(self, input: Option<String>) -> Self
The name of the prepared statement to delete.
Sourcepub fn get_statement_name(&self) -> &Option<String>
pub fn get_statement_name(&self) -> &Option<String>
The name of the prepared statement to delete.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup to which the statement to be deleted belongs.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup to which the statement to be deleted belongs.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup to which the statement to be deleted belongs.